# STOPWORDS-TR
#### AUTHOR: [Metin Oktay DENIZ](https://www.metindeniz.com)
Stop words for Turkish.


## Installation / Kurulum

```bash
pip install stopwords_tr
```

## Usage / Kullaným

```bash
>>> import stopwords_tr as stp

>>> stp.stopwords() #Stopwords Array List
'ben','sen','o'...

>>> stp.stopwordsSpace() #Stopwords String List But There Are Spaces at the Beginning and End of the Words
' ben ',' sen ',' o '...
```